
grant execute on nydex.SJS2NYDEX to sjs;

create or replace
PACKAGE BODY         SJS.SEAL   IS

-- $Id: PACKAGE_BODY_SJS_SEAL.sql,v 1.10 2007/07/03 19:44:03 adrury Exp $

--------------------------------------------------------------------------------
-- private utility fx
--------------------------------------------------------------------------------

  -- Virtual seal for AI
  procedure seal_ai_(return_out out number, message_out out varchar2, a_id_in in sjs.Arrest.a_id%type, agcy_ori_in in sjs.Arrest.agcy_ori%type)
  is
   l_cnt pls_integer := 0;
  begin
   if ('Y' = 'N') then sjs.p$dbg('begin seal_ai_(a_id=>'||a_id_in||', agcy_ori=>'||agcy_ori_in||')','seal_ai_('||a_id_in||','||agcy_ori_in||')'); end if;
   if (1 <> sys_context('SJS','secmx_arrest_seal')) then
     return_out := 0;
     message_out := 'SECMX_ARREST_SEAL must be included in user''s security matrix to seal AIs'; sjs.p$dbg(message_out,'seal_ai_('||a_id_in||','||agcy_ori_in||')');
     return;
   end if;
   if ('Y' = 'N') then sjs.p$dbg(' update v$ai_defendant','seal('||a_id_in||','||agcy_ori_in||')'); end if;
   update sjs.v$ai_defendant
      set is_sealed = 1
    where 1 = sys_context('SJS','secmx_arrest_seal')
      and 0 = is_sealed
      and a_agcy_ori = agcy_ori_in
      and a_arrest_num = (
             select a.a_arrest_num
               from sjs.s$arrests a
              where a.a_id = a_id_in
                and a.agcy_ori = agcy_ori_in
           ) ;
   l_cnt := sql%rowcount ; if ('Y' = 'N') then sjs.p$dbg(' sql%rowcount='||l_cnt,'seal_ai_('||a_id_in||','||agcy_ori_in||')'); end if;
   if (0 < l_cnt) then
    return_out := 1 ;
   else
    return_out := 0 ;
   end if;
   message_out := l_cnt || ' row(s) sealed for AI defendant(s)';
   if ('Y' = 'N') then sjs.p$dbg('end seal_ai_(a_id=>'||a_id_in||', agcy_ori=>'||agcy_ori_in||') '||message_out,'seal_ai_'); end if;
  exception when others then
   return_out := 0 ;
   message_out := 'Problem sealing AI: '||sqlerrm;
   sjs.p$dbg(message_out,'seal_ai_('||a_id_in||','||agcy_ori_in||')');
  end seal_ai_ ;

  -- Virtual seal for SDEP
  procedure seal_sdep_(return_out out number, message_out out varchar2, a_id_in in sjs.Arrest.a_id%type, agcy_ori_in in sjs.Arrest.agcy_ori%type)
  is
   l_cnt pls_integer := 0;
  begin
   if ('Y' = 'N') then sjs.p$dbg('begin seal_sdep_(a_id=>'||a_id_in||', agcy_ori=>'||agcy_ori_in||')','seal_sdep_('||a_id_in||','||agcy_ori_in||')'); end if;
   if (1 <> sys_context('SJS','secmx_arrest_seal')) then
     return_out := 0;
     message_out := 'SECMX_ARREST_SEAL must be included in user''s security matrix to seal sdeps'; sjs.p$dbg(message_out,'seal_sdep_('||a_id_in||','||agcy_ori_in||')');
     return;
   end if;
   if ('Y' = 'N') then sjs.p$dbg(' update v$sdep_defendant','seal_sdep_('||a_id_in||','||agcy_ori_in||')'); end if;
   update sjs.v$sdep_defendant
      set is_sealed = 1
    where 1 = sys_context('SJS','secmx_arrest_seal')
      and 0 = is_sealed
      and a_agcy_ori = agcy_ori_in
      and a_arrest_num = (
             select a.a_arrest_num
               from sjs.s$arrests a
              where a.a_id = a_id_in
                and a.agcy_ori = agcy_ori_in
           ) ;
   l_cnt := sql%rowcount ; if ('Y' = 'N') then sjs.p$dbg(' sql%rowcount='||l_cnt,'seal_sdep_('||a_id_in||','||agcy_ori_in||')'); end if;
   if (0 < l_cnt) then
    return_out := 1 ;
   else
    return_out := 0 ;
   end if;
   message_out := l_cnt || ' row(s) sealed for SDEP defendant(s)';
   if ('Y' = 'N') then sjs.p$dbg('end seal_sdep_(a_id=>'||a_id_in||', agcy_ori=>'||agcy_ori_in||')','seal_sdep_('||a_id_in||','||agcy_ori_in||')'); end if;
  exception when others then
   return_out := 0 ;
   message_out := 'Problem sealing SDEP: '||sqlerrm;
   sjs.p$dbg(message_out,'seal_sdep_('||a_id_in||','||agcy_ori_in||')');
  end seal_sdep_ ;

  -- Virtual seal for REPORT_SNAPSHOT PDFs
  procedure seal_rpt_(return_out out number, message_out out varchar2,
                      type_in in sjs.report_snapshot.rpt_type_id%type,
                      id_in in number,
                      agcy_ori_in in sjs.sjs_agency.agcy_ori%type)
  is
   l_cnt pls_integer := 0;
  begin
   if ('Y' = 'N') then sjs.p$dbg('begin seal_rpt_(type=>'||type_in||', id=>'||id_in||', agcy_ori=>'||agcy_ori_in||')','seal_rpt_('||type_in||','||id_in||','||agcy_ori_in||')'); end if;
   if (1 <> sys_context('SJS','secmx_arrest_seal')) then
     return_out := 0;
     message_out := 'SECMX_ARREST_SEAL must be included in user''s security matrix to seal report snapshots'; sjs.p$dbg(message_out,'seal_rpt_('||type_in||','||id_in||','||agcy_ori_in||')');
     return;
   end if;
   if ('Y' = 'N') then sjs.p$dbg(' update report_snapshot','seal_rpt_('||type_in||','||id_in||','||agcy_ori_in||')'); end if;
   update sjs.report_snapshot
      set is_sealed = 1
    where 1 = sys_context('SJS','secmx_arrest_seal')
      and id = id_in
      and agcy_ori = agcy_ori_in
      and rpt_type_id = type_in
      and is_sealed = 0 ;
   l_cnt := sql%rowcount ; if ('Y' = 'N') then sjs.p$dbg(' sql%rowcount='||l_cnt,'seal_rpt_('||type_in||','||id_in||','||agcy_ori_in||')'); end if;
   if (0 < l_cnt) then
    return_out := 1 ;
   else
    return_out := 0 ;
   end if;
   message_out := l_cnt || ' REPORT_SNAPSHOT row(s) sealed';
   if ('Y' = 'N') then sjs.p$dbg('end seal_rpt_(type=>'||type_in||', id=>'||id_in||', agcy_ori=>'||agcy_ori_in||')','seal_rpt_('||type_in||','||id_in||','||agcy_ori_in||')'); end if;
  exception when others then
   return_out := 0 ;
   message_out := 'Problem sealing RPT: '||sqlerrm;
   sjs.p$dbg(message_out,'seal_rpt_('||type_in||','||id_in||','||agcy_ori_in||')');
  end seal_rpt_ ;

--------------------------------------------------------------------------------
-- public fx (most of which shouldn't be public)
--------------------------------------------------------------------------------

    /* Dynamic SQL to execute received statements */
  FUNCTION run_sql(sql_statement VARCHAR2) RETURN BOOLEAN IS
    cursor_name    INTEGER;
    rows_processed INTEGER;
    parse_string   VARCHAR2(2000) := sql_statement;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg(parse_string,'seal.run_sql'); end if;
    cursor_name := dbms_sql.open_cursor;
    dbms_sql.parse(cursor_name,parse_string,1);
    rows_processed := dbms_sql.execute(cursor_name);
    dbms_sql.close_cursor(cursor_name);
    RETURN TRUE;
  EXCEPTION WHEN OTHERS THEN
    sjs.p$dbg(sqlerrm,'seal.run_sql');
    dbms_sql.close_cursor(cursor_name);
    RAISE;
    RETURN FALSE;
  END run_sql;

    /* Procedure to clear sjsseal.SealedArrest table*/
  PROCEDURE clear_seal(v_return OUT INTEGER, v_message OUT VARCHAR2) IS
    sql_string VARCHAR2(4000);
    success_flag BOOLEAN;
  BEGIN
    sql_string := 'DELETE FROM sjsseal.SealedArrest';
    if ('Y' = 'N') then sjs.p$dbg(sql_string,'seal.clear_seal'); end if;
    success_flag := run_sql(sql_string);
    IF success_flag THEN
      v_return := 1;
      v_message := 'Successfully cleared.';
    ELSE
      v_return := 0;
      v_message := 'Clear failed.';
    END IF;
  END clear_seal;

    /* Utility function for locking the loaded records table*/
  PROCEDURE checklock_seal(v_return OUT INTEGER, v_message OUT VARCHAR2) IS
    sql_string   VARCHAR2(4000);
    success_flag BOOLEAN;
    counter_var  INTEGER := 0;
    CURSOR get_lock_cur IS
      SELECT count(1) counter
        FROM sjsseal.SealedArrest;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('checklock_seal','seal.checklock_seal'); end if;
    FOR get_lock_rec IN get_lock_cur LOOP
      counter_var := get_lock_rec.counter;
    END LOOP;
    IF counter_var = 0 THEN
      v_return := 1;
      v_message := 'Locked sealing process';
    ELSE
      v_return := 0;
      v_message := 'Seal process is locked be another user.';
   END IF;
  END checklock_seal;

    /* Procedure for preparing the loaded records for an entire arrest*/
  PROCEDURE arrest_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,seal_charge IN VARCHAR2) IS
    return_var   INTEGER;
    message_var  VARCHAR2(4000);
    sql_string   VARCHAR2(4000);
    success_flag BOOLEAN;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('begin arrest_seal(arrest_id=>'||arrest_id||', seal_charge=>'||seal_charge||')','seal.arrest_seal('||arrest_id||','||seal_charge||')'); end if;
    sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,a_delete_id,seal_type,a_agcy_ori)
                     VALUES ('||arrest_id||','||arrest_id||',''A'','''||global_agcy_ori||''')';
    success_flag := run_sql(sql_string);
    FOR get_arrestcharges_rec in get_arrestcharges_cur(arrest_id) LOOP
      charge_seal(return_var,message_var,arrest_id,get_arrestcharges_rec.ac_id,'A',seal_charge);
      arrestchargesweapons_seal(return_var,message_var,arrest_id,get_arrestcharges_rec.ac_id,'A');
      arrestweapon_seal(return_var,message_var,arrest_id,'A');
      arrestnarrative_seal(return_var,message_var,arrest_id,'A');
      arrestpeople_seal(return_var,message_var,arrest_id,'A');
      v_return := return_var;
      v_message := message_var;
      IF return_var != 1 THEN
        v_return := 0;
        v_message := message_var;
        EXIT;
      END IF;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('end arrest_seal(arrest_id=>'||arrest_id||', seal_charge=>'||seal_charge||')','seal.arrest_seal('||arrest_id||','||seal_charge||')'); end if;
  END arrest_seal;

    /* Procedure for preparing the loaded records for a single charge of an arrest */
  PROCEDURE charge_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,charge_id IN NUMBER,seal_type IN VARCHAR2,seal_charge IN VARCHAR2) IS
    sql_string       VARCHAR2(4000);
    success_flag     BOOLEAN;
    defendant_id_var NUMBER(18);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('begin charge_seal(arrest_id=>'||arrest_id||', charge_id=>'||charge_id||', seal_type=>'||seal_type||', seal_charge=>'||seal_charge||')','seal.charge_seal('||arrest_id||','||charge_id||','||seal_type||','||seal_charge||')'); end if;
    FOR get_defendant_rec IN get_defendant_cur(arrest_id) LOOP
      defendant_id_var := get_defendant_rec.defendant_id;
    END LOOP;
    sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,defendant_id,ac_id,seal_charge,seal_type,a_agcy_ori)
                     VALUES ('||arrest_id||','||defendant_id_var||','||charge_id||','''||seal_charge||''','''||seal_type||''','''||global_agcy_ori||''')';
    success_flag := run_sql(sql_string);
    IF success_flag THEN
      v_return := 1;
      v_message := 'Arrest '||arrest_id||', charge '||charge_id||' loaded';
    ELSE
      v_return := 0;
      v_message := 'Arrest '||arrest_id||', charge '||charge_id||' Failed sealing';
    END IF;
    if ('Y' = 'N') then sjs.p$dbg('end charge_seal(arrest_id=>'||arrest_id||', charge_id=>'||charge_id||', seal_type=>'||seal_type||', seal_charge=>'||seal_charge||')','seal.charge_seal('||arrest_id||','||charge_id||','||seal_type||','||seal_charge||')'); end if;
  END charge_seal;

    /* Procedure for preparing the loaded records for all weapons of a charge */
  PROCEDURE arrestchargesweapons_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,charge_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('arrestchargesweapons_seal(arrest_id=>'||arrest_id||', charge_id=>'||charge_id||', seal_type=>'||seal_type||')','seal.arrestchargesweapons_seal'); end if;
    v_return := 1;
    v_message := 'No ArrestChargeWeapons for arrest '||arrest_id;
    FOR get_chargesweapons_rec IN get_Chargesweapons_cur(charge_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,acw_id,seal_type,a_agcy_ori)
                       VALUES ('||arrest_id||','||get_chargesweapons_rec.acw_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', ArrestChargesWeapons '||get_chargesweapons_rec.acw_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', ArrestChargesWeapons '||get_chargesweapons_rec.acw_id||' Failed sealing';
      END IF;
    END LOOP;
  END arrestchargesweapons_seal;

    /* Procedure for preparing the loaded records for all weapons for an arrest */
  PROCEDURE arrestweapon_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('arrestweapon_seal(arrest_id=>'||arrest_id||', seal_type=>'||seal_type||')','seal.arrestweapon_seal'); end if;
    v_return := 1;
    v_message := 'No ArrestWeapon for arrest - '||arrest_id;
    FOR get_arrestweapons_rec IN get_arrestweapons_cur(arrest_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,aw_id,seal_type,a_agcy_ori)
                       VALUES ('||arrest_id||','||get_arrestweapons_rec.aw_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', weaopn '||get_arrestweapons_rec.aw_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', weapon '||get_arrestweapons_rec.aw_id||' Failed sealing';
      END IF;
    END LOOP;
  END arrestweapon_seal;

    /* Procedure for preparing the loaded records for all narratives for an arrest */
  PROCEDURE arrestnarrative_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('arrestnarrative_seal(arrest_id=>'||arrest_id||', seal_type=>'||seal_type||')','seal.arrestnarrative_seal'); end if;
    v_return := 1;
    v_message := 'No narrative for arrest - '||arrest_id;
    FOR get_arrestnarrative_rec IN get_arrestnarrative_cur(arrest_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,an_id,seal_type,a_agcy_ori)
                       VALUES ('||arrest_id||','||get_arrestnarrative_rec.an_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', ArrestNarrative '||get_arrestnarrative_rec.an_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', ArrestNarrative '||get_arrestnarrative_rec.an_id||' Failed sealing';
      END IF;
      narrative_seal(return_var,message_var,arrest_id,NULL,NULL,get_arrestnarrative_rec.n_id,'A');
      IF return_var !=1 THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', narrative '||get_arrestnarrative_rec.n_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', narrative '||get_arrestnarrative_rec.n_id||' Failed sealing';
      END IF;
    END LOOP;
  END arrestnarrative_seal;

    /* Procedure for preparing the loaded records for narrative */
  PROCEDURE narrative_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,incident_id IN NUMBER,warrant_id IN NUMBER,narrative_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
  BEGIN
      if ('Y' = 'N') then sjs.p$dbg('narrative_seal(arrest_id=>'||arrest_id||', incident_id=>'||incident_id||', warrant_id=>'||warrant_id||', narrative_id=>'||narrative_id||', seal_type=>'||seal_type||')','seal.narrative_seal'); end if;
      sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,i_id,w_id,n_id,seal_type,a_agcy_ori)
                       VALUES ('''||arrest_id||''','''||incident_id||''','''||warrant_id||''','''||narrative_id||''','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', narrative '||narrative_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', narrative '||narrative_id||' Failed sealing';
      END IF;
  END narrative_seal;

    /* Procedure for preparing the loaded records for all people for an arrest */
  PROCEDURE arrestpeople_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('arrestpeople_seal(arrest_id=>'||arrest_id||', seal_type=>'||seal_type||')','seal.arrestpeople_seal'); end if;
    v_return := 1;
    v_message := 'No ArrestPeople for arrest '||arrest_id;
    FOR get_arrestpeople_rec IN get_arrestpeople_cur(arrest_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,ap_id,seal_type,a_agcy_ori)
                       VALUES ('||arrest_id||','||get_arrestpeople_rec.ap_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', person '||get_arrestpeople_rec.ap_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', person '||get_arrestpeople_rec.ap_id||' Failed sealing';
      END IF;
      people_seal(return_var,message_var,arrest_id,get_arrestpeople_rec.pd_id,'A');
      IF return_var =1 THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', people '||get_arrestpeople_rec.pd_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', people '||get_arrestpeople_rec.pd_id||' Failed sealing';
      END IF;
    END LOOP;
  END arrestpeople_seal;

    /* Procedure for preparing the loaded records for PersonDetail */
  PROCEDURE people_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,pd_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
  BEGIN
      if ('Y' = 'N') then sjs.p$dbg('people_seal(arrest_id=>'||arrest_id||', pd_id=>'||pd_id||', seal_type=>'||seal_type||')','seal.people_seal'); end if;
      ------------------------------------------------------------------------------------
      -- It's possible here to get weird stuff like arrest_id=N, seal_type='I'
      -- where N is actually an I_ID. Don't know what that does downstream.
      ------------------------------------------------------------------------------------
      sql_string := 'INSERT INTO sjsseal.SealedArrest(a_id,pd_id,seal_type,a_agcy_ori)
                       VALUES ('||arrest_id||','||pd_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', PersonDetail '||pd_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', PersonDetail '||pd_id||' Failed sealing';
      END IF;
  END people_seal;

  /* Procedure for preparing the loaded records for an incident arrest */
  PROCEDURE incident_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,arrest_id IN NUMBER,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
      if ('Y' = 'N') then sjs.p$dbg('begin incident_seal(arrest_id=>'||arrest_id||', incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incident_seal('||arrest_id||','||incident_id||','||seal_type||')'); end if;
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,i_delete_id,seal_type,a_agcy_ori)
                       VALUES ('||incident_id||','||incident_id||',''I'','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Arrest '||arrest_id||', incident '||incident_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Arrest '||arrest_id||', incident '||incident_id||' Failed sealing';
      END IF;
      incidentnarrative_seal(return_var,message_var,incident_id,'I');
      incidentweapons_seal(return_var,message_var,incident_id,'I');
      incidentcharges_seal(return_var,message_var,incident_id,'I');
      incidentvehicles_seal(return_var,message_var,incident_id,'I');
      incidentproperty_seal(return_var,message_var,incident_id,'I');
      incidentpeople_seal(return_var,message_var,incident_id,'I');
      incidentwarrant_seal(return_var,message_var,incident_id,'I');
      if ('Y' = 'N') then sjs.p$dbg('end incident_seal(arrest_id=>'||arrest_id||', incident_id=>'||incident_id||', seal_type=>'||seal_type||')','incident_seal('||arrest_id||','||incident_id||','||seal_type||')'); end if;
  END incident_seal;

    /* Procedure for preparing the loaded records for all narratives for an incident */
  PROCEDURE incidentnarrative_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentnarrative_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentnarrative_seal'); end if;
    FOR get_incidentnarrative_rec IN get_incidentnarrative_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,in_id,seal_type,a_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentnarrative_rec.in_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentNarrative '||get_incidentnarrative_rec.in_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentNarrative '||get_incidentnarrative_rec.in_id||' Failed sealing';
      END IF;
      narrative_seal(return_var,message_var,NULL,incident_id,NULL,get_incidentnarrative_rec.n_id,'I');
      IF return_var =1 THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', narrative '||get_incidentnarrative_rec.n_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', narrative '||get_incidentnarrative_rec.n_id||' Failed sealing';
      END IF;
    END LOOP;
  END incidentnarrative_seal;

    /* Procedure for preparing the loaded records for all weapons for an incident */
  PROCEDURE incidentweapons_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentweapons_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentweapons_seal'); end if;
    FOR get_incidentweapons_rec IN get_incidentweapons_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,iwpns_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentweapons_rec.iwpns_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentWeapons '||get_incidentweapons_rec.iwpns_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', incidentweapons '||get_incidentweapons_rec.iwpns_id||' Failed sealing';
      END IF;
    END LOOP;
  END incidentweapons_seal;

    /* Procedure for preparing the loaded records for all charges for an incident */
  PROCEDURE incidentcharges_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentcharges_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentcharges_seal'); end if;
    FOR get_incidentcharges_rec IN get_incidentcharges_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,ic_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentcharges_rec.ic_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentCharges '||get_incidentcharges_rec.ic_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentCharges '||get_incidentcharges_rec.ic_id||' Failed sealing';
      END IF;
      victimincidentoffense_seal(return_var,message_var,incident_id,get_incidentcharges_rec.ic_id,'I');
      incidentoffenseweapons_seal(return_var,message_var,incident_id,get_incidentcharges_rec.ic_id,'I');
    END LOOP;
  END incidentcharges_seal;

    /* Procedure for preparing the loaded records for all VIO associations for an incident */
  PROCEDURE victimincidentoffense_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,incidentcharge_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('victimincidentoffense_seal(incident_id=>'||incident_id||', incidentcharge_id=>'||incidentcharge_id||', seal_type=>'||seal_type||')','seal.victimincidentoffense_seal'); end if;
    FOR get_victimincidentoffense_rec IN get_victimincidentoffense_cur(incidentcharge_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,vio_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_victimincidentoffense_rec.vio_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', VictimIncidentOffense '||get_victimincidentoffense_rec.vio_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', VictimIncidentOffense '||get_victimincidentoffense_rec.vio_id||' Failed sealing';
      END IF;
    END LOOP;
  END victimincidentoffense_seal;

    /* Procedure for preparing the loaded records for all IncidentOffenseWeapons for an incident */
  PROCEDURE incidentoffenseweapons_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,incidentcharge_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentoffenseweapons_seal(incident_id=>'||incident_id||', incidentcharge_id=>'||incidentcharge_id||', seal_type=>'||seal_type||')','seal.incidentoffenseweapons_seal'); end if;
    FOR get_incidentoffenseweapons_rec IN get_incidentoffenseweapons_cur(incidentcharge_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,iow_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentoffenseweapons_rec.iow_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentOffenseWeapons '||get_incidentoffenseweapons_rec.iow_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentOffenseWeapons '||get_incidentoffenseweapons_rec.iow_id||' Failed sealing';
      END IF;
    END LOOP;
  END incidentoffenseweapons_seal;

    /* Procedure for preparing the loaded records for all vehicles for an incident */
  PROCEDURE incidentvehicles_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentvehicles_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentvehicles_seal'); end if;
    FOR get_incidentvehicles_rec IN get_incidentvehicles_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,iv_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentvehicles_rec.iv_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentVehicles '||get_incidentvehicles_rec.iv_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentVehicles '||get_incidentvehicles_rec.iv_id||' Failed sealing';
      END IF;
    END LOOP;
  END incidentvehicles_seal;

    /* Procedure for preparing the loaded records for all property for an incident */
  PROCEDURE incidentproperty_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentproperty_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentproperty_seal'); end if;
    FOR get_incidentproperty_rec IN get_incidentproperty_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,iprop_id,seal_type,i_agcy_ori) VALUES ('||incident_id||','||get_incidentproperty_rec.iprop_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentProperty '||get_incidentproperty_rec.iprop_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentProperty '||get_incidentproperty_rec.iprop_id||' Failed sealing';
      END IF;
    END LOOP;
  END incidentproperty_seal;

    /* Procedure for preparing the loaded records for all people for an incident */
  procedure incidentpeople_seal(v_return out integer, v_message out varchar2,incident_id in number,seal_type in varchar2) is
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentpeople_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentpeople_seal'); end if;
    FOR get_incidentpeople_rec IN get_incidentpeople_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,ip_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentpeople_rec.ip_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentPeople '||get_incidentpeople_rec.ip_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentPeople '||get_incidentpeople_rec.ip_id||' Failed sealing';
      END IF;
      victimsuspect_seal(return_var,message_var,incident_id,get_incidentpeople_rec.ip_id,'I');
      people_seal(return_var,message_var,incident_id,get_incidentpeople_rec.pd_id,'I');
    END LOOP;
  END incidentpeople_seal;

    /* Procedure for preparing the loaded records for all VS associations for an incident */
  procedure victimsuspect_seal(v_return out integer, v_message out varchar2,incident_id in number,incidentpeople_id in number,seal_type in varchar2) is
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('victimsuspect_seal(incident_id=>'||incident_id||', incidentpeople_id=>'||incidentpeople_id||', seal_type=>'||seal_type||')','seal.victimsuspect_seal'); end if;
    FOR get_victimsuspect_rec IN get_victimsuspect_cur(incidentpeople_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,vs_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_victimsuspect_rec.vs_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', VictimSuspect '||get_victimsuspect_rec.vs_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', VictimSuspect '||get_victimsuspect_rec.vs_id||' Failed sealing';
      END IF;
    END LOOP;
  END victimsuspect_seal;

    /* Procedure for preparing the loaded records for all warrants for an incident */
  PROCEDURE incidentwarrant_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('incidentwarrant_seal(incident_id=>'||incident_id||', seal_type=>'||seal_type||')','seal.incidentwarrant_seal'); end if;
    FOR get_incidentwarrant_rec IN get_incidentwarrant_cur(incident_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(i_id,w_id,seal_type,i_agcy_ori)
                       VALUES ('||incident_id||','||get_incidentwarrant_rec.w_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Incident '||incident_id||', IncidentWarrant '||get_incidentwarrant_rec.w_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Incident '||incident_id||', IncidentWarrant '||get_incidentwarrant_rec.w_id||' Failed sealing';
      END IF;
      warrantcharges_seal(return_var,message_var,incident_id,get_incidentwarrant_rec.w_id,'W');
    END LOOP;
  END incidentwarrant_seal;

    /* Procedure for preparing the loaded records for all WarrantCharges for a warrant */
  PROCEDURE warrantcharges_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,warrant_id IN OUT NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
    counter_var     INTEGER :=0;
    warrant_id2     NUMBER(18);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('warrantcharges_seal(incident_id=>'||incident_id||', warrant_id=>'||warrant_id||', seal_type=>'||seal_type||')','seal.warrantcharges_seal'); end if;
    FOR get_warrantcharges_rec IN get_warrantcharges_cur(warrant_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(w_id,wc_id,seal_type,w_agcy_ori)
                       VALUES ('||get_warrantcharges_rec.w_id||','||get_warrantcharges_rec.wc_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Warrant '||get_warrantcharges_rec.w_id||', WarrantCharges '||get_warrantcharges_rec.wc_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||get_warrantcharges_rec.w_id||', WarrantCharges '||get_warrantcharges_rec.wc_id||' Failed sealing';
      END IF;
      counter_var := counter_var +1;
      warrant_id2 := get_warrantcharges_rec.w_id;
    END LOOP;
    IF counter_var = 1 THEN
      warrant_seal(return_var,message_var,incident_id,warrant_id2,'W');
    END IF;
  END warrantcharges_seal;

    /* Procedure for preparing the loaded records for all warrants for an incident */
  PROCEDURE warrant_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,warrant_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
    counter_var     INTEGER :=0;
  BEGIN
      if ('Y' = 'N') then sjs.p$dbg('warrant_seal(incident_id=>'||incident_id||', warrant_id=>'||warrant_id||', seal_type=>'||seal_type||')','seal.warrant_seal'); end if;
      sql_string := 'INSERT INTO sjsseal.SealedArrest(w_id,w_delete_id,seal_type,w_agcy_ori)
                       VALUES ('||warrant_id||','||warrant_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Warrant '||warrant_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||warrant_id||' Failed sealing';
      END IF;
      warrantassignment_seal(return_var,message_var,incident_id,warrant_id,'W');
      warrantpeople_seal(return_var,message_var,incident_id,warrant_id,'W');
      warrantnarrative_seal(return_var,message_var,incident_id,warrant_id,'W');
      IF return_var =1 THEN
        v_return := 1;
        v_message := 'Warrant '||warrant_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||warrant_id||' Failed sealing';
      END IF;
  END warrant_seal;

-- TODO: incident/arrest assignment seal ?

    /* Procedure for preparing the loaded records for all WarrantAssignments for a warrant */
  PROCEDURE warrantassignment_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,warrant_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
    counter_var     INTEGER :=0;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('warrantassignment_seal(incident_id=>'||incident_id||', warrant_id=>'||warrant_id||', seal_type=>'||seal_type||')','seal.warrantassignment_seal'); end if;
    FOR get_warrantassignment_rec IN get_warrantassignment_cur(warrant_id) LOOP
       sql_string := 'INSERT INTO sjsseal.SealedArrest(w_id,wa_id,seal_type,w_agcy_ori)
                       VALUES ('||warrant_id||','||get_warrantassignment_rec.wa_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Warrant '||warrant_id||', WarrantAssignment '||get_warrantassignment_rec.wa_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||warrant_id||', WarrantAssignment '||get_warrantassignment_rec.wa_id||' Failed sealing';
      END IF;
    END LOOP;
  END warrantassignment_seal;

    /* Procedure for preparing the loaded records for all people for a warrant */
  PROCEDURE warrantpeople_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,warrant_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
    counter_var     INTEGER :=0;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('warrantpeople_seal(incident_id=>'||incident_id||', warrant_id=>'||warrant_id||', seal_type=>'||seal_type||')','seal.warrantpeople_seal'); end if;
    FOR get_warrantpeople_rec IN get_warrantpeople_cur(warrant_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(w_id,wp_id,seal_type,w_agcy_ori)
                       VALUES ('||warrant_id||','||get_warrantpeople_rec.wp_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Warrant '||warrant_id||', WarrantPeople '||get_warrantpeople_rec.wp_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||warrant_id||', WarrantPeople '||get_warrantpeople_rec.wp_id||' Failed sealing';
      END IF;
      people_seal(return_var,message_var,warrant_id,get_warrantpeople_rec.pd_id,'W');
    END LOOP;
    FOR get_warrantdefendant_rec IN get_warrantdefendant_cur(warrant_id) LOOP
      people_seal(return_var,message_var,warrant_id,get_warrantdefendant_rec.defendant_id,'W');
    END LOOP;
    FOR get_complainant_rec IN get_complainant_cur(warrant_id) LOOP
      people_seal(return_var,message_var,warrant_id,get_complainant_rec.complainant_id,'W');
    END LOOP;
  END warrantpeople_seal;

    /* Procedure for preparing the loaded records for all narratives for a warrant */
  PROCEDURE warrantnarrative_seal(v_return OUT INTEGER, v_message OUT VARCHAR2,incident_id IN NUMBER,warrant_id IN NUMBER,seal_type IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    return_var      INTEGER;
    message_var     VARCHAR2(4000);
    counter_var     INTEGER :=0;
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('warrantnarrative_seal(incident_id=>'||incident_id||', warrant_id=>'||warrant_id||', seal_type=>'||seal_type||')','seal.warrantnarrative_seal'); end if;
    FOR get_warrantnarrative_rec IN get_warrantnarrative_cur(warrant_id) LOOP
      sql_string := 'INSERT INTO sjsseal.SealedArrest(w_id,wn_id,seal_type,w_agcy_ori)
                       VALUES ('||warrant_id||','||get_warrantnarrative_rec.wn_id||','''||seal_type||''','''||global_agcy_ori||''')';
      success_flag := run_sql(sql_string);
      IF success_flag THEN
        v_return := 1;
        v_message := 'Warrant '||warrant_id||', WarrantNarrative '||get_warrantnarrative_rec.wn_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||warrant_id||', WarrantNarrative '||get_warrantnarrative_rec.wn_id||' Failed sealing';
      END IF;
      narrative_seal(return_var,message_var,NULL,NULL,warrant_id,get_warrantnarrative_rec.n_id,'W');
      IF return_var =1 THEN
        v_return := 1;
        v_message := 'Warrant '||warrant_id||', WarrantNarrative '||get_warrantnarrative_rec.n_id||' loaded';
      ELSE
        v_return := 0;
        v_message := 'Warrant '||warrant_id||', WarrantNarrative '||get_warrantnarrative_rec.n_id||' Failed sealing';
      END IF;
    END LOOP;
  END warrantnarrative_seal;

-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-- Public procedures
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
-------------------------------------------------------------------------------

  /* Main procedure for loading primary keys for sealed records by charge id */
  PROCEDURE load_seal_charge(p_return OUT INTEGER, p_message OUT VARCHAR2, seal_flag OUT VARCHAR2,arrestcharge IN NUMBER,seal_charge IN VARCHAR2,u_name_in IN VARCHAR2,agcy_ori_in VARCHAR2) IS
    num_charges   INTEGER := 0;
    num_arrest    INTEGER := 0;
    arrest_id     NUMBER;
    message       VARCHAR2(2000);
    v_return      INTEGER;
    v_message     VARCHAR2(2000);
    seal_type_var VARCHAR2(2);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('load_seal_charge(arrestcharge=>'||arrestcharge||', seal_charge=>'||seal_charge||', agcy_ori_in=>'||agcy_ori_in||')','seal.load_seal_charge'); end if;
    global_u_name := u_name_in;
    global_agcy_ori := agcy_ori_in;
    checklock_seal(p_return,p_message);
    p_return := 1;
    IF p_return = 1 THEN
      p_return := 0;
      p_message := 'Arrest charge '||arrestcharge||' not yet processed';
      FOR get_arrest_rec IN get_arrest_cur(arrestcharge) LOOP
        num_charges := num_charges+1;
        arrest_id := get_arrest_rec.a_id;
      END LOOP;
      ----------------------------------------------------------------------------------------------
      -- virtually seal AI_DEFENDANTS and REPORT_SNAPSHOT PDFs (over-inclusively)
      seal_ai_(p_return, p_message, arrest_id, global_agcy_ori );
      seal_rpt_(p_return, p_message, 3 /*AI*/, arrest_id, global_agcy_ori );
      -- virtually seal SDEP_DEFENDANTS and REPORT_SNAPSHOT PDFs (over-inclusively)
      seal_sdep_(p_return, p_message, arrest_id, global_agcy_ori );
      seal_rpt_(p_return, p_message, 4 /*SDEP*/, arrest_id, global_agcy_ori );
      -- virtually seal Arrest REPORT_SNAPSHOT PDFs (over-inclusively)
      seal_rpt_(p_return, p_message, 2 /*ARREST*/, arrest_id, global_agcy_ori );
      ----------------------------------------------------------------------------------------------
      IF num_charges = 0 THEN
        p_return := 0;
        p_message := 'No arrest charge found for ID '||arrestcharge;
      ELSIF num_charges = 1 THEN
        seal_type_var := 'A';
        seal_flag := 'A';
        -- for Arrest with one charge, load whole arrest for sealing
        arrest_seal(p_return,p_message,arrest_id,seal_charge);
        FOR get_incidentarrest_rec IN get_incidentarrest_cur(arrestcharge) LOOP
          -- load all Incidents associated with charge in ArrestCharges for sealing
          incident_seal(p_return,p_message,arrest_id,get_incidentarrest_rec.i_id,seal_type_var);
        END LOOP;
        FOR get_seal_charge_rec IN get_seal_charge_cur(arrest_id) LOOP
          message := get_seal_charge_rec.message;
        END LOOP;
      ELSIF num_charges > 1 THEN
        seal_type_var := 'AC';
        -- load ArrestChargesWeapons for sealing
        arrestchargesweapons_seal(p_return,p_message,arrest_id,arrestcharge,seal_type_var);
        -- load ArrestCharges for sealing
        charge_seal(p_return,p_message,arrest_id,arrestcharge,seal_type_var,seal_charge);
        seal_flag := 'AC';
        FOR get_incidentarrest_rec IN get_incidentarrest_cur(arrestcharge) LOOP
          -- load all Incidents associated with charge in ArrestCharges for sealing
          incident_seal(p_return,p_message,arrest_id,get_incidentarrest_rec.i_id,seal_type_var);
        END LOOP;
      END IF;
      copy_seal(v_return,v_message,u_name_in);
    --COMMIT;
    ELSE
        p_return := 0;
        p_message := 'Lock Seal Failed';
    END IF;
    FOR get_seal_charge_rec IN get_seal_charge_cur(arrest_id) LOOP
      message := get_seal_charge_rec.message;
    END LOOP;
    IF p_return = 1 THEN
      p_message := message;
    END IF;
  END load_seal_charge;

  /* Main procedure for loading primary keys for sealed records by incident id */
  PROCEDURE load_seal_incident(p_return OUT INTEGER, p_message OUT VARCHAR2,arrest_id IN NUMBER,seal_charge IN VARCHAR2,incident_id IN NUMBER,u_name_in IN VARCHAR2,agcy_ori_in VARCHAR2) IS
    CURSOR get_arrestcharges_cur(a_id_in NUMBER,i_id_in NUMBER) IS
      SELECT ac.ac_id
        FROM arrestcharges ac
        WHERE (ac.a_id = a_id_in AND ac.agcy_ori = global_agcy_ori)
        AND (ac.i_id = i_id_in AND ac.i_agcy_ori = global_agcy_ori);
    seal_flag        VARCHAR2(2);
    seal_type_var    VARCHAR2(2);
    message          VARCHAR2(2000);
  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('load_seal_incident(arrest_id=>'||arrest_id||', seal_charge=>'||seal_charge||', incident_id=>'||incident_id||', agcy_ori_in=>'||agcy_ori_in||')','seal.load_seal_incident'); end if;
    global_u_name := u_name_in;
    global_u_name := u_name_in;
    global_agcy_ori := agcy_ori_in;
    checklock_seal(p_return,p_message);
    IF p_return = 1 THEN
    -- load and delete all charges for specified Incident
    FOR a IN get_arrestcharges_cur(arrest_id,incident_id) LOOP
      ----------------------------------------------------------------------------------------------
      -- virtually seal Incident REPORT_SNAPSHOT PDFs (over-inclusively)
      seal_rpt_(p_return, p_message, 1 /*INCIDENT*/, incident_id, global_agcy_ori );
      ----------------------------------------------------------------------------------------------
      load_seal_charge(p_return,p_message,seal_flag,a.ac_id,seal_charge,global_u_name,global_agcy_ori);
      delete_seal(p_return,p_message,global_agcy_ori);
    END LOOP;
    ELSE
        p_return := 0;
        p_message := 'Lock Seal Failed';
    END IF;
  EXCEPTION WHEN  others THEN
    DBMS_OUTPUT.PUT_LINE(p_message);
    ROLLBACK;
    DELETE FROM sjsseal.SealedArrest;
  --COMMIT;
    p_return := 0;
    p_message := 'Load seal failed and rolled back. '||sqlerrm;
  END load_seal_incident;

    /* Main procedure for deleting production records*/
  PROCEDURE delete_seal(p_return OUT INTEGER, p_message OUT VARCHAR2,agcy_ori_in IN VARCHAR2) IS
    sql_string           VARCHAR2(4000);
    sql_string2          VARCHAR2(4000);
    PersonMaster_id      NUMBER(18);
    pm_count_var         INTEGER;
    pd_count_var         INTEGER;
    IncidentPeople_count INTEGER;
    defendant_count_var  INTEGER;
    success_flag         BOOLEAN;
    failure              EXCEPTION;
   CURSOR delete_arrestnarrative_cur IS
    SELECT DISTINCT 'DELETE FROM ArrestNarrative WHERE an_id = '||an_id statement
      FROM sjsseal.SealedArrest
      WHERE an_id IS NOT NULL;
   CURSOR delete_chargesweapons_cur IS
    SELECT DISTINCT 'DELETE FROM ArrestChargesWeapons WHERE acw_id = '||acw_id statement
      FROM sjsseal.SealedArrest
      WHERE acw_id IS NOT NULL;
   CURSOR delete_arrestcharges_cur IS
    SELECT DISTINCT 'DELETE FROM ArrestCharges WHERE ac_id = '||ac_id statement
      FROM sjsseal.SealedArrest
      WHERE ac_id IS NOT NULL;
   CURSOR delete_arrestpeople_cur IS
    SELECT DISTINCT 'DELETE FROM ArrestPeople WHERE ap_id = '||ap_id statement
      FROM sjsseal.SealedArrest
      WHERE ap_id IS NOT NULL;
   CURSOR delete_arrestweapons_cur IS
    SELECT DISTINCT 'DELETE FROM ArrestWeapons WHERE aw_id = '||aw_id statement
      FROM sjsseal.SealedArrest
      WHERE aw_id IS NOT NULL;
   CURSOR delete_ish_cur IS
    SELECT DISTINCT 'DELETE FROM ImSubmissionHistory WHERE pd_id IN (SELECT defendant_id FROM arrest WHERE a_id = '||a_id||' AND agcy_ori = '''||global_agcy_ori||''')' statement
      FROM sjsseal.SealedArrest
      WHERE a_id IS NOT NULL;
   CURSOR delete_ith_cur IS
    SELECT DISTINCT 'DELETE FROM ImTransactionHistory WHERE pd_id IN (SELECT defendant_id FROM arrest WHERE a_id = '||a_id||' AND agcy_ori = '''||global_agcy_ori||''')' statement
      FROM sjsseal.SealedArrest
      WHERE a_id IS NOT NULL;
   CURSOR delete_ire_cur IS
    SELECT DISTINCT 'DELETE FROM ImResponseErrors WHERE ith_id IN (SELECT ith_id FROM imtransactionhistory WHERE pd_id IN (SELECT defendant_id FROM arresT WHERE a_id = '||a_id||' AND agcy_ori = '''||global_agcy_ori||'''))' statement
      FROM sjsseal.SealedArrest
      WHERE a_id IS NOT NULL;
   CURSOR delete_arrest_cur IS
    SELECT DISTINCT 'DELETE FROM Arrest WHERE a_id = '||a_delete_id||' AND agcy_ori = '''||global_agcy_ori||'''' statement
      FROM sjsseal.SealedArrest
      WHERE a_delete_id IS NOT NULL;
   CURSOR delete_warrantnarrative_cur IS
    SELECT DISTINCT 'DELETE FROM WarrantNarrative WHERE wn_id = '||sa.wn_id statement
      FROM sjsseal.SealedArrest sa
      WHERE sa.wn_id IS NOT NULL
      AND sa.w_id IN (SELECT w_id FROM warrant WHERE defendant_id IN
                      (SELECT pd_id FROM PersonDetail WHERE pm_id IN
                       (SELECT pm_id FROM PersonDetail WHERE pd_id IN
                        (SELECT defendant_id FROM sjsseal.SealedArrest))));
   CURSOR delete_warrantassignment_cur IS
    SELECT DISTINCT 'DELETE FROM WarrantAssignment WHERE wa_id = '||sa.wa_id statement
      FROM sjsseal.SealedArrest sa
      WHERE sa.wa_id IS NOT NULL
      AND sa.w_id IN (SELECT w_id FROM warrant WHERE defendant_id IN
                      (SELECT pd_id FROM PersonDetail WHERE pm_id IN
                       (SELECT pm_id FROM PersonDetail WHERE pd_id IN
                        (SELECT defendant_id FROM sjsseal.SealedArrest))));
   CURSOR delete_warrantpeople_cur IS
    SELECT DISTINCT 'DELETE FROM WarrantPeople WHERE wp_id = '||sa.wp_id statement
      FROM sjsseal.SealedArrest sa
      WHERE sa.wp_id IS NOT NULL
      AND sa.w_id IN (SELECT w_id FROM warrant WHERE defendant_id IN
                      (SELECT pd_id FROM PersonDetail WHERE pm_id IN
                       (SELECT pm_id FROM PersonDetail WHERE pd_id IN
                        (SELECT defendant_id FROM sjsseal.SealedArrest))));
   CURSOR delete_warrantcharges_cur IS
    SELECT DISTINCT 'DELETE FROM WarrantCharges WHERE wc_id = '||sa.wc_id statement
      FROM sjsseal.SealedArrest sa
      WHERE sa.wc_id IS NOT NULL
      AND sa.w_id IN (SELECT w_id FROM warrant WHERE defendant_id IN
                      (SELECT pd_id FROM PersonDetail WHERE pm_id IN
                       (SELECT pm_id FROM PersonDetail WHERE pd_id IN
                        (SELECT defendant_id FROM sjsseal.SealedArrest))));
   CURSOR delete_warrant_cur IS
    SELECT DISTINCT 'DELETE FROM Warrant WHERE w_id = '||sa.w_delete_id statement, sa.w_delete_id w_id
      FROM sjsseal.SealedArrest sa
      WHERE sa.w_delete_id IS NOT NULL
      AND sa.w_id IN (SELECT w_id FROM warrant WHERE defendant_id IN
                      (SELECT pd_id FROM PersonDetail WHERE pm_id IN
                       (SELECT pm_id FROM PersonDetail WHERE pd_id IN
                        (SELECT defendant_id FROM sjsseal.SealedArrest))));
/*
   CURSOR delete_incidentwarrant_cur IS
    SELECT DISTINCT 'DELETE FROM IncidentWarrant WHERE iw_id = '||sa.iw_id statement
      FROM sjsseal.SealedArrest sa
      WHERE sa.iw_id IS NOT NULL
      AND sa.w_id IN (SELECT w_id FROM warrant WHERE defendant_id IN
                      (SELECT pd_id FROM PersonDetail WHERE pm_id IN
                       (SELECT pm_id FROM PersonDetail WHERE pd_id IN
                        (SELECT defendant_id FROM sjsseal.SealedArrest))));
*/
   CURSOR get_PersonDetail_cur IS
     SELECT DISTINCT pd_id
       FROM sjsseal.SealedArrest
       WHERE seal_type = 'A'
     UNION
     SELECT DISTINCT defendant_id
       FROM sjsseal.SealedArrest
     UNION
     select pd_id from PersonDetail where pm_id in (
       select distinct pm_id from PersonDetail where pd_id in(
         select distinct defendant_id from sjsseal.SealedArrest));
   CURSOR PersonDetail_count_cur(pd_id_in NUMBER) IS
     SELECT pd_id
       FROM ArrestPeople
       WHERE pd_id = pd_id_in
     UNION
     SELECT pd_id
       FROM IncidentPeople
       WHERE pd_id = pd_id_in
     UNION
     SELECT pd_id
       FROM Nsor
       WHERE pd_id = pd_id_in
     UNION
     SELECT pd_id
       FROM WarrantPeople
       WHERE pd_id = pd_id_in
     UNION
     SELECT defendant_id
       FROM Arrest
       WHERE defendant_id = pd_id_in
     UNION
     SELECT defendant_id
       FROM Warrant
       WHERE defendant_id = pd_id_in
     UNION
     SELECT complainant_id
       FROM Warrant
       WHERE complainant_id = pd_id_in;
   CURSOR get_PersonMaster_cur(pd_id_in NUMBER) IS
     SELECT DISTINCT pm_id
       FROM PersonDetail
       WHERE pd_id = pd_id_in;
   CURSOR get_pmcount_cur(pm_id_in NUMBER) IS
     SELECT count(1) counter
       FROM PersonDetail
       WHERE pm_id = pm_id_in;
   CURSOR get_IncidentPeople_cur(pd_id_in NUMBER) IS
    SELECT ip_id
      FROM IncidentPeople ip
      WHERE ip.pd_id = pd_id_in;
   CURSOR get_IncidentPeople_count_cur(pd_id_in NUMBER) IS
    SELECT ac_id
      FROM ArrestCharges ac, IncidentPeople ip, arrest a
      WHERE ac.i_id = ip.i_id
      AND ac.a_id = a.a_id
      AND (ip.pd_id=pd_id_in)
      AND a.defendant_id IN (SELECT defendant_id FROM sjsseal.SealedArrest);
    CURSOR get_IncidentPeople_count (pd_id_in NUMBER) IS
    SELECT pd_id
      FROM sjsseal.SealedArrest
      WHERE pd_id = pd_id_in
      AND pd_id IN (SELECT pd_id FROM IncidentPeople WHERE i_id IN (SELECT i_delete_id FROM sjsseal.SealedArrest));
    CURSOR get_defendant_count_cur(pd_id_in NUMBER) IS
      SELECT defendant_id
        FROM arrest
        WHERE defendant_id = pd_id_in
      UNION
      SELECT defendant_id
        FROM warrant
        WHERE defendant_id = pd_id_in
      UNION
      SELECT defendant_id
        FROM warrant
        WHERE complainant_id = pd_id_in;
   CURSOR get_alias_cur(pm_id_in NUMBER) IS
     SELECT DISTINCT alias_id
       FROM alias
       WHERE pm_id = pm_id_in;
   CURSOR get_personphone_cur(pd_id_in NUMBER) IS
     SELECT DISTINCT pp_id
       FROM personphone
       WHERE pd_id = pd_id_in;
   CURSOR get_address_cur(pd_id_in NUMBER) IS
     SELECT DISTINCT NVL(add_id,0) ADD_ID
       FROM PersonDetail
       WHERE pd_id = pd_id_in;
   CURSOR get_employer_cur(pd_id_in NUMBER) IS
     SELECT DISTINCT emp_id,add_id
       FROM employer
       WHERE pd_id = pd_id_in;

  CURSOR get_nydex_arrest_seal IS
      SELECT DISTINCT a_id,i_id,seal_type
         FROM sjsseal.sealedarrest
         where seal_type in ('A','AC')
         ;
       v_nydex_return    VARCHAR2(100);
       v_nydex_iid number(23);
       v_nydex_participation char(1);

  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('delete_seal(agcy_ori_in=>'||agcy_ori_in||')','seal.delete_seal'); end if;

   BEGIN
   select NYDEX_PARTICIPATION into v_nydex_participation
   from sjs_agency 
   where agcy_ori=agcy_ori_in;
   
   if v_nydex_participation='Y' then
   FOR i IN get_nydex_arrest_seal LOOP
            select distinct i_id into v_nydex_iid
            from sjsseal.sealedarrest
            where i_id is not null
        ;
         v_nydex_return := nydex.SJS2NYDEX.LOG_SEALED_RECORD(v_nydex_iid,agcy_ori_in,i.a_id,i.seal_type);
	  null;
   END LOOP;
   end if;
   EXCEPTION
    when others then
        p_return := 0;
        p_message := 'Logging into NYDEX log table failed';
        RAISE failure;
   END;

    global_agcy_ori := agcy_ori_in;
    FOR delete_arrestnarrative_rec IN delete_arrestnarrative_cur LOOP
      sql_string := delete_arrestnarrative_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete arrestnarrative failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_chargesweapons_rec IN delete_chargesweapons_cur LOOP
      sql_string := delete_chargesweapons_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete arrestchargesweapons failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_arrestcharges_rec IN delete_arrestcharges_cur LOOP
      sql_string := delete_arrestcharges_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete arrestcharges failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_arrestpeople_rec IN delete_arrestpeople_cur LOOP
      sql_string := delete_arrestpeople_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete arrestpeople failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_arrestweapons_rec IN delete_arrestweapons_cur LOOP
      sql_string := delete_arrestweapons_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete arrestweapons failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_ish_rec IN delete_ish_cur LOOP
      sql_string := delete_ish_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete imsubmissionhistory failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_ire_rec IN delete_ire_cur LOOP
      sql_string := delete_ire_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete imresponseerrors failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_ith_rec IN delete_ith_cur LOOP
      sql_string := delete_ith_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete imtransactionhistory failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_arrest_rec IN delete_arrest_cur LOOP
      sql_string := delete_arrest_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete arrest failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR get_PersonDetail_rec IN get_PersonDetail_cur LOOP
      pd_count_var := 0;
      defendant_count_var := 0;
      IncidentPeople_count := 0;
      FOR a IN get_IncidentPeople_count_cur(get_PersonDetail_rec.pd_id) LOOP
dbms_output.put_line('pd_id-'||get_PersonDetail_rec.pd_id||' IN INCIDENT PEOPLE');
        pd_count_var := pd_count_var+1;
      END LOOP;
      FOR a IN get_defendant_count_cur(get_PersonDetail_rec.pd_id) LOOP
        defendant_count_var := defendant_count_var+1;
      END LOOP;
      FOR a IN get_IncidentPeople_count(get_PersonDetail_rec.pd_id) LOOP
        IncidentPeople_count := IncidentPeople_count+1;
      END LOOP;
dbms_output.put_line('pd_id-'||get_PersonDetail_rec.pd_id||' ip count-'||pd_count_var||' defendant count-'||defendant_count_var||' IncidentPeople-'||IncidentPeople_count);
    IF get_PersonDetail_rec.pd_id IS NOT NULL AND (pd_count_var = 0 AND defendant_count_var = 0) AND IncidentPeople_count != 0 THEN
        FOR get_IncidentPeople_rec IN get_IncidentPeople_cur(get_PersonDetail_rec.pd_id) LOOP
          sql_string := 'UPDATE incidentproperty SET ip_id=NULL WHERE ip_id = '||get_IncidentPeople_rec.ip_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
          sql_string := 'UPDATE incidentvehicles SET ip_id=NULL WHERE ip_id = '||get_IncidentPeople_rec.ip_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
          sql_string := 'DELETE FROM victimsuspect WHERE ip_victim_id = '||get_IncidentPeople_rec.ip_id||' OR  ip_suspect_id = '||get_IncidentPeople_rec.ip_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
          sql_string := 'DELETE FROM victimincidentoffense WHERE ip_id = '||get_IncidentPeople_rec.ip_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
        END LOOP;
        sql_string := 'DELETE FROM IncidentPeople WHERE pd_id = '||get_PersonDetail_rec.pd_id;
dbms_output.put_line('string-'||sql_string);
        success_flag := run_sql(sql_string);
    FOR delete_warrantnarrative_rec IN delete_warrantnarrative_cur LOOP
      sql_string := delete_warrantnarrative_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete warrantnarrative failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_warrantassignment_rec IN delete_warrantassignment_cur LOOP
      sql_string := delete_warrantassignment_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete warrantassignment failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_warrantpeople_rec IN delete_warrantpeople_cur LOOP
      sql_string := delete_warrantpeople_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete warrantpeople failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_warrantcharges_rec IN delete_warrantcharges_cur LOOP
      sql_string := delete_warrantcharges_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete warrantcharges failed';
        RAISE failure;
      END IF;
    END LOOP;
    FOR delete_warrant_rec IN delete_warrant_cur LOOP
      DELETE FROM warrantcontact WHERE w_id = delete_warrant_rec.w_id AND agcy_ori = global_agcy_ori;
      sql_string := delete_warrant_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete warrant failed';
        RAISE failure;
      END IF;
    END LOOP;
/*
    FOR delete_incidentwarrant_rec IN delete_incidentwarrant_cur LOOP
      sql_string := delete_incidentwarrant_rec.statement;
dbms_output.put_line('string-'||sql_string);
      success_flag := run_sql(sql_string);
      IF NOT success_flag THEN
        p_return := 0;
        p_message := 'Delete incidentwarrant failed';
        RAISE failure;
      END IF;
    END LOOP;
*/
    END IF;
      pd_count_var := 0;
      FOR a IN PersonDetail_count_cur(get_PersonDetail_rec.pd_id) LOOP
        pd_count_var := pd_count_var+1;
      END LOOP;
      IF pd_count_var = 0  THEN
        IF get_PersonDetail_rec.pd_id IS NOT NULL THEN
          sql_string := 'DELETE FROM employer WHERE pd_id = '||get_PersonDetail_rec.pd_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
        END IF;
        FOR get_employer_rec IN get_employer_cur(get_PersonDetail_rec.pd_id) LOOP
          IF get_employer_rec.add_id IS NOT NULL THEN
            sql_string := 'DELETE FROM address WHERE add_id = '||get_employer_rec.add_id;
dbms_output.put_line('string-'||sql_string);
            success_flag := run_sql(sql_string);
          END IF;
        END LOOP;
        FOR get_address_rec IN get_address_cur(get_PersonDetail_rec.pd_id) LOOP
          sql_string2 := 'DELETE FROM address WHERE add_id = '||get_address_rec.add_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
        END LOOP;
        IF get_PersonDetail_rec.pd_id IS NOT NULL THEN
          FOR get_person_master_rec IN get_PersonMaster_cur(get_PersonDetail_rec.pd_id) LOOP
            PersonMaster_id := get_person_master_rec.pm_id;
          END LOOP;
            sql_string := 'DELETE FROM PersonDetail WHERE pd_id = '||get_PersonDetail_rec.pd_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
        END IF;
        IF sql_string2 IS NOT NULL THEN
          success_flag := run_sql(sql_string2);
        END IF;
        FOR get_pmcount_rec IN get_pmcount_cur(PersonMaster_id) LOOP
          pm_count_var := get_pmcount_rec.counter;
        END LOOP;
        IF PersonMaster_id IS NOT NULL AND pm_count_var = 0 THEN
          sql_string := 'DELETE FROM alias WHERE pm_id = '||PersonMaster_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
          sql_string := 'DELETE FROM PersonMaster WHERE pm_id = '||PersonMaster_id;
dbms_output.put_line('string-'||sql_string);
          success_flag := run_sql(sql_string);
        END IF;
      END IF;
    END LOOP;
    sql_string := 'DELETE FROM sjsseal.SealedArrest'; --commented by vinay for debugging
    success_flag := run_sql(sql_string);
    COMMIT;
    p_return := 1;
    p_message := 'Delete Seal successfully completed';
  EXCEPTION WHEN  failure THEN
    DBMS_OUTPUT.PUT_LINE(p_message);
    ROLLBACK;
    DELETE FROM sjsseal.SealedArrest;
  --COMMIT;
    p_return := 0;
    p_message := 'Delete Seal failed and rolled back. '||sqlerrm;
  WHEN  others THEN
    DBMS_OUTPUT.PUT_LINE(p_message);
    ROLLBACK;
    DELETE FROM sjsseal.SealedArrest;
  --COMMIT;
    p_return := 0;
    p_message := 'Delete Seal failed and rolled back. '||sqlerrm;
  END delete_seal;

    /* Main procedure for copying production records*/
  PROCEDURE copy_seal(p_return OUT INTEGER, p_message OUT VARCHAR2, p_u_name IN VARCHAR2) IS
    sql_string      VARCHAR2(4000);
    success_flag    BOOLEAN;
    failure         EXCEPTION;
    CURSOR sa_arrest_cur IS
      SELECT DISTINCT a_id
        FROM sjsseal.SealedArrest
        WHERE seal_type = 'A';
    CURSOR arrest_cur (a_id_in NUMBER) IS
      SELECT a_id,a_date,agcy_ori,defendant_id,a_reference_number,a_case_num,a_juvenile,juvenilestatusid,arrestee_stat
        FROM arrest
        WHERE a_id = a_id_in
        AND agcy_ori = global_agcy_ori;
    CURSOR sa_arrestcharges_cur IS
      SELECT DISTINCT ac_id,seal_charge
        FROM sjsseal.SealedArrest
        WHERE seal_type = 'A';
    CURSOR arrestcharges_cur (ac_id_in NUMBER) IS
      SELECT a_id,i_id,ac_id,ac_attempt,law_ordinal,larc_theft
        FROM arrestcharges
        WHERE ac_id = ac_id_in
        AND agcy_ori = global_agcy_ori;
    CURSOR sa_arrestnarrative_cur IS
      SELECT DISTINCT an_id
        FROM sjsseal.SealedArrest;
    CURSOR arrestnarrative_cur (an_id_in NUMBER) IS
      SELECT a_id,an_id,n_id
        FROM arrestnarrative
        WHERE an_id = an_id_in
        AND an_id NOT IN (select an_id from sjsseal.sealed_arrestnarrative);
    CURSOR sa_narrative_cur IS
      SELECT DISTINCT n_id
        FROM sjsseal.SealedArrest;
    CURSOR narrative_cur (n_id_in NUMBER) IS
      SELECT n_id,/*n_text,*/n_text_clob,n_date_written
        FROM narrative
        WHERE n_id = n_id_in
        AND n_id NOT IN (select n_id from sjsseal.sealed_narrative);
    CURSOR sa_ac_arrest_cur IS
      SELECT DISTINCT sa.a_id,sa.ac_id,sa.seal_charge,sa.defendant_id
        FROM sjsseal.SealedArrest sa
        WHERE sa.seal_type = 'AC'
        AND SA.ac_id IS NOT NULL;
    CURSOR ac_narrative(ac_id_in NUMBER) IS
      SELECT a_id,an_id,n_id
        FROM arrestnarrative
        WHERE a_id IN (SELECT a_id FROM arrestcharges WHERE ac_id = ac_id_in)
        AND an_id NOT IN (select an_id from sjsseal.sealed_arrestnarrative)
        AND agcy_ori = global_agcy_ori;
    CURSOR arrestweapons_cur IS
      SELECT aw_id,a_id,weapons_id
        FROM arrestweapons
        WHERE a_id IN (SELECT a_id FROM sjsseal.SealedArrest)
        AND agcy_ori = global_agcy_ori;
    CURSOR IncidentPeople_cur IS
     SELECT ip.i_id,ip.ip_id,ip.pd_id,vs.vs_id,vs.ip_victim_id,vs.ip_suspect_id,vs.relationshipid
       FROM IncidentPeople ip,
            victimsuspect vs
       WHERE ip.ip_id = vs.ip_suspect_id (+)
       AND ip.i_id IN (SELECT i_id FROM sjsseal.SealedArrest)
       AND ip.agcy_ori = global_agcy_ori;
    CURSOR sa_PersonDetail_cur IS
      SELECT DISTINCT defendant_id
      FROM sjsseal.SealedArrest
      WHERE seal_type= 'A';
    CURSOR PersonDetail_cur(pd_id_in NUMBER) IS
      SELECT pd_id,pm_id,pd_sex,raceid,pd_agerange,ethnicid,conditionid,arrestresidency,persontypeid
      FROM PersonDetail
      WHERE pd_id = pd_id_in;
    CURSOR PersonMaster_cur(pm_id_in NUMBER) IS
      SELECT pm_id,pm_last_name,pm_first_name,pm_ssn,pm_dob,pm_nysid
      FROM PersonMaster
      WHERE pm_id = pm_id_in;
    CURSOR sa_warrant_cur IS
      SELECT DISTINCT w_id
        FROM sjsseal.SealedArrest
        WHERE seal_type = 'W';
    CURSOR warrant_cur (w_id_in NUMBER) IS
      SELECT w_id,w_number,agcy_ori,defendant_id
        FROM warrant
        WHERE w_id = w_id_in
        AND agcy_ori = global_agcy_ori;
    CURSOR sa_warrantcharges_cur IS
      SELECT DISTINCT wc_id
        FROM sjsseal.SealedArrest
        WHERE seal_type = 'W';
    CURSOR warrantcharges_cur (wc_id_in NUMBER) IS
      SELECT w_id,wc_id
        FROM WarrantCharges
        WHERE wc_id = wc_id_in
        AND agcy_ori = global_agcy_ori;
/*
    CURSOR sa_incidentwarrant_cur IS
      SELECT DISTINCT iw_id
        FROM sjsseal.SealedArrest;
    CURSOR incidentwarrant_cur (iw_id_in NUMBER) IS
      SELECT i_id,iw_id
        FROM incidentwarrant
        WHERE iw_id = iw_id_in
        AND agcy_ori = global_agcy_ori;
*/
    CURSOR sa_incident_cur IS
      SELECT DISTINCT i_id
        FROM sjsseal.SealedArrest
        WHERE seal_type = 'I';
    CURSOR incident_cur (i_id_in NUMBER) IS
      SELECT i_id,agcy_ori
        FROM incident
        WHERE i_id = i_id_in
        AND agcy_ori = global_agcy_ori;

  BEGIN
    if ('Y' = 'N') then sjs.p$dbg('begin seal.copy_seal(p_u_name=>'||p_u_name||')','seal.copy_seal'); end if;
    if ('Y' = 'N') then sjs.p$dbg('sa_arrest_cur','seal.copy_seal'); end if;
    FOR a IN sa_arrest_cur LOOP
      FOR b IN arrest_cur(a.a_id) LOOP
        INSERT INTO sjsseal.sealed_arrest(a_id,a_date,agcy_ori,defendant_id,a_reference_number,a_case_num,a_juvenile,juvenilestatusid,arrestee_stat,a_ent_date,u_name)
          VALUES(b.a_id,b.a_date,b.agcy_ori,b.defendant_id,b.a_reference_number,b.a_case_num,b.a_juvenile,b.juvenilestatusid,b.arrestee_stat,sysdate,p_u_name);
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_arrestcharges_cur','seal.copy_seal'); end if;
    FOR a IN sa_arrestcharges_cur LOOP
      FOR b IN arrestcharges_cur(a.ac_id) LOOP
        INSERT INTO sjsseal.sealed_arrestcharges(a_id,i_id,agcy_ori,i_agcy_ori,ac_id,ac_attempt,law_ordinal,seal_charge,larc_theft,ac_ent_date,u_name)
          VALUES(b.a_id,b.i_id,global_agcy_ori,global_agcy_ori,b.ac_id,b.ac_attempt,b.law_ordinal,a.seal_charge,b.larc_theft,sysdate,p_u_name);
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_arrestnarrative_cur','seal.copy_seal'); end if;
    FOR a IN sa_arrestnarrative_cur LOOP
      FOR b IN arrestnarrative_cur(a.an_id) LOOP
        INSERT INTO sjsseal.sealed_arrestnarrative(a_id,agcy_ori,an_id,n_id,an_ent_date,u_name)
          VALUES(b.a_id,global_agcy_ori,b.an_id,b.n_id,sysdate,p_u_name);
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_narrative_cur','seal.copy_seal'); end if;
    FOR a IN sa_narrative_cur LOOP
      FOR b IN narrative_cur(a.n_id) LOOP
        INSERT INTO sjsseal.sealed_narrative(n_id,/*n_text,*/n_text_clob,n_date_written,n_ent_date,u_name)
          VALUES(b.n_id,/*b.n_text,*/b.n_text_clob,b.n_date_written,sysdate,p_u_name);
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('arrestweapons_cur','seal.copy_seal'); end if;
    FOR c IN arrestweapons_cur LOOP
      INSERT INTO sjsseal.sealed_arrestweapons(aw_id,a_id,agcy_ori,weapons_id,aw_ent_date,u_name)
        VALUES(c.aw_id,c.a_id,global_agcy_ori,c.weapons_id,sysdate,p_u_name);
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('incidentpeople_cur','seal.copy_seal'); end if;
    FOR a IN incidentpeople_cur LOOP
      INSERT INTO sjsseal.sealed_incidentpeople(i_id,agcy_ori,ip_id,pd_id,ip_ent_date,u_name)
        VALUES(a.i_id,global_agcy_ori,a.ip_id,a.pd_id,sysdate,p_u_name);
      IF a.vs_id IS NOT NULL THEN
        INSERT INTO sjsseal.sealed_victimsuspect(vs_id,ip_suspect_id,ip_victim_id,relationshipid,vs_ent_date,u_name)
          VALUES(a.vs_id,a.ip_suspect_id,a.ip_victim_id,a.relationshipid,sysdate,p_u_name);
      END IF;
      if ('Y' = 'N') then sjs.p$dbg('persondetail_cur','seal.copy_seal'); end if;
      FOR b IN persondetail_cur(a.pd_id) LOOP
        INSERT INTO sjsseal.sealed_persondetail(pd_id,pm_id,pd_sex,raceid,pd_agerange,ethnicid,conditionid,arrestresidency,persontypeid,pd_ent_date,u_name)
          VALUES(b.pd_id,b.pm_id,b.pd_sex,b.raceid,b.pd_agerange,b.ethnicid,b.conditionid,b.arrestresidency,b.persontypeid,sysdate,p_u_name);
        if ('Y' = 'N') then sjs.p$dbg('personmaster_cur','seal.copy_seal'); end if;
        FOR c IN personmaster_cur(b.pm_id) LOOP
          INSERT INTO sjsseal.sealed_PersonMaster(pm_id,pm_last_name,pm_first_name,pm_dob,pm_ssn,pm_nysid,pm_ent_date,u_name)
            VALUES(c.pm_id,c.pm_last_name,c.pm_first_name,c.pm_dob,c.pm_ssn,c.pm_nysid,sysdate,p_u_name);
        END LOOP;
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_persondetail_cur','seal.copy_seal'); end if;
    FOR a IN sa_persondetail_cur LOOP
      if ('Y' = 'N') then sjs.p$dbg('persondetail_cur','seal.copy_seal'); end if;
      FOR b IN persondetail_cur(a.defendant_id) LOOP
        INSERT INTO sjsseal.sealed_persondetail(pd_id,pm_id,pd_sex,raceid,pd_agerange,ethnicid,conditionid,arrestresidency,persontypeid,pd_ent_date,u_name)
          VALUES(b.pd_id,b.pm_id,b.pd_sex,b.raceid,b.pd_agerange,b.ethnicid,b.conditionid,b.arrestresidency,b.persontypeid,sysdate,p_u_name);
        if ('Y' = 'N') then sjs.p$dbg('personmaster_cur','seal.copy_seal'); end if;
        FOR c IN personmaster_cur(b.pm_id) LOOP
          INSERT INTO sjsseal.sealed_PersonMaster(pm_id,pm_last_name,pm_first_name,pm_dob,pm_ssn,pm_nysid,pm_ent_date,u_name)
            VALUES(c.pm_id,c.pm_last_name,c.pm_first_name,c.pm_dob,c.pm_ssn,c.pm_nysid,sysdate,p_u_name);
        END LOOP;
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_ac_arrest_cur','seal.copy_seal'); end if;
    FOR a IN sa_ac_arrest_cur LOOP
      if ('Y' = 'N') then sjs.p$dbg('arrest_cur','seal.copy_seal'); end if;
      FOR b IN arrest_cur(a.a_id) LOOP
        INSERT INTO sjsseal.sealed_arrest(a_id,a_date,agcy_ori,defendant_id,a_reference_number,a_case_num,a_juvenile,juvenilestatusid,arrestee_stat)
          VALUES(b.a_id,b.a_date,b.agcy_ori,b.defendant_id,b.a_reference_number,b.a_case_num,b.a_juvenile,b.juvenilestatusid,b.arrestee_stat);
      END LOOP;
      if ('Y' = 'N') then sjs.p$dbg('arrestcharges_cur','seal.copy_seal'); end if;
      FOR b IN arrestcharges_cur(a.ac_id) LOOP
        if ('Y' = 'N') then sjs.p$dbg('a_id='||b.a_id||';i_id='||b.i_id||';global_agcy_ori='||global_agcy_ori||';ac_id='||b.ac_id||';law_ordinal='||b.law_ordinal||';seal_charge='||a.seal_charge||';ac_attempt='||b.ac_attempt||';larc_theft='||b.larc_theft,'seal.copy_seal'); end if;
        INSERT INTO sjsseal.sealed_arrestcharges(a_id,i_id,agcy_ori,i_agcy_ori,ac_id,law_ordinal,seal_charge,ac_attempt,larc_theft,ac_ent_date,u_name)
          VALUES(b.a_id,b.i_id,global_agcy_ori,global_agcy_ori,b.ac_id,b.law_ordinal,a.seal_charge,b.ac_attempt,b.larc_theft,sysdate,p_u_name);
      END LOOP;
      if ('Y' = 'N') then sjs.p$dbg('ac_narrative','seal.copy_seal'); end if;
      FOR b IN ac_narrative(a.ac_id) LOOP
        if ('Y' = 'N') then sjs.p$dbg('arrestnarrative_cur','seal.copy_seal'); end if;
        FOR c IN arrestnarrative_cur(b.an_id) LOOP
          INSERT INTO sjsseal.sealed_arrestnarrative(a_id,agcy_ori,an_id,n_id,an_ent_date,u_name)
            VALUES(c.a_id,global_agcy_ori,c.an_id,c.n_id,sysdate,p_u_name);
        END LOOP;
        if ('Y' = 'N') then sjs.p$dbg('narrative_cur','seal.copy_seal'); end if;
        FOR c IN narrative_cur(b.n_id) LOOP
          INSERT INTO sjsseal.sealed_narrative(n_id,/*n_text,*/n_text_clob,n_date_written,n_ent_date,u_name)
            VALUES(c.n_id,/*c.n_text,*/c.n_text_clob,c.n_date_written,sysdate,p_u_name);
        END LOOP;
      END LOOP;
      if ('Y' = 'N') then sjs.p$dbg('persondetail_cur','seal.copy_seal'); end if;
      FOR b IN persondetail_cur(a.defendant_id) LOOP
        INSERT INTO sjsseal.sealed_persondetail(pd_id,pm_id,pd_sex,raceid,pd_agerange,ethnicid,conditionid,arrestresidency,persontypeid,pd_ent_date,u_name)
          VALUES(b.pd_id,b.pm_id,b.pd_sex,b.raceid,b.pd_agerange,b.ethnicid,b.conditionid,b.arrestresidency,b.persontypeid,sysdate,p_u_name);
        if ('Y' = 'N') then sjs.p$dbg('personmaster_cur','seal.copy_seal'); end if;
        FOR c IN personmaster_cur(b.pm_id) LOOP
          INSERT INTO sjsseal.sealed_PersonMaster(pm_id,pm_last_name,pm_first_name,pm_dob,pm_ssn,pm_nysid,pm_ent_date,u_name)
            VALUES(c.pm_id,c.pm_last_name,c.pm_first_name,c.pm_dob,c.pm_ssn,c.pm_nysid,sysdate,p_u_name);
        END LOOP;
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_warrant_cur','seal.copy_seal'); end if;
    FOR a IN sa_warrant_cur LOOP
      if ('Y' = 'N') then sjs.p$dbg('warrant_cur','seal.copy_seal'); end if;
      FOR b IN warrant_cur(a.w_id) LOOP
        INSERT INTO sjsseal.sealed_warrant(w_id,w_number,agcy_ori,defendant_id,w_ent_date,u_name)
          VALUES(b.w_id,b.w_number,b.agcy_ori,b.defendant_id,sysdate,p_u_name);
      END LOOP;
    END LOOP;
    if ('Y' = 'N') then sjs.p$dbg('sa_warrantcharges_cur','seal.copy_seal'); end if;
    FOR a IN sa_warrantcharges_cur LOOP
      FOR b IN warrantcharges_cur(a.wc_id) LOOP
        INSERT INTO sjsseal.sealed_warrantcharges(w_id,agcy_ori,wc_id,iw_id,wc_ent_date,u_name)
          VALUES(b.w_id,global_agcy_ori,b.wc_id,NULL,sysdate,p_u_name);
      END LOOP;
    END LOOP;
/*
    FOR a IN sa_incidentwarrant_cur LOOP
      FOR b IN incidentwarrant_cur(a.iw_id) LOOP
        INSERT INTO sjsseal.sealed_incidentwarrant(i_id,agcy_ori,iw_id,iw_ent_date,u_name)
          VALUES(b.i_id,global_agcy_ori,b.iw_id,sysdate,p_u_name);
      END LOOP;
    END LOOP;
*/
    if ('Y' = 'N') then sjs.p$dbg('sa_incident_cur','seal.copy_seal'); end if;
    FOR a IN sa_incident_cur LOOP
      if ('Y' = 'N') then sjs.p$dbg('incident_cur','seal.copy_seal'); end if;
      FOR b IN incident_cur(a.i_id) LOOP
        INSERT INTO sjsseal.sealed_incident(i_id,agcy_ori,i_ent_date,u_name)
          VALUES(b.i_id,b.agcy_ori,sysdate,p_u_name);
      END LOOP;
    END LOOP;
    p_return := 1;
    p_message := 'Copy Seal successfully completed';
    if ('Y' = 'N') then sjs.p$dbg('end seal.copy_seal','seal.copy_seal'); end if;
  exception when others then
    sjs.p$dbg(sqlerrm, 'seal.copy_seal');
    raise;
  END copy_seal;

END Seal;

/

